@@ -14,6 +14,7 @@
 /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
 #include <iostream>
 #include "StcCmd.hpp"
+#include "ClientToServerCmd.hpp"
 
 std::ostream& StcCmd::print(std::ostream& os) const
 {
@@ -22,6 +23,7 @@ std::ostream& StcCmd::print(std::ostream& os) const
 		case StcCmd::BLOCK_CLIENT_SERVER_HALTED:  return os << "cmd:Server_halted"; break;
 		case StcCmd::BLOCK_CLIENT_ON_HOME_SERVER: return os << "cmd:Wait"; break;
 		case StcCmd::BLOCK_CLIENT_ZOMBIE:         return os << "cmd:Zombie"; break;
+		case StcCmd::INVALID_ARGUMENT:            return os << "cmd:Invalid_argumnet"; break;
 		default: assert(false); break;
  	}
 	assert(false); // unknown command
@@ -53,6 +55,16 @@ bool StcCmd::handle_server_response( ServerReply& server_reply, Cmd_ptr cts_cmd,
 			server_reply.set_block_client_zombie_detected(); // requires further work, by ClientInvoker
 			break;
  		}
+		case StcCmd::INVALID_ARGUMENT: {
+			// This is created on the client side, after detecting a INVALID_ARGUMENT reply from the server
+			// This keeps compatibility with 4 servers
+			if (debug) std::cout << "  StcCmd::handle_server_response INVALID_ARGUMENT\n";
+			server_reply.set_invalid_argument();// requires further work, by ClientInvoker
+			std::stringstream ss;
+			ss << "Error: request( "; cts_cmd->print(ss); ss << " ) failed! Server replied with: invalid_argument(Could not decode client protocol)\n";
+			server_reply.set_error_msg(ss.str());
+			break;
+ 		}
 		default: assert(false); break;
  	}
 	return ret;
